@@ -455,6 +455,26 @@ test('create a new action with limits', t => {
   return actions.create({ name: '12345', action, limits })
 })
 
+test('create a new action with concurrency setting', t => {
+  t.plan(4)
+  const ns = '_'
+  const client = {}
+  const action = 'function main() { // main function body};'
+  const limits = {
+    concurrency: 2
+  }
+  const actions = new Actions(client)
+
+  client.request = (method, path, options) => {
+    t.is(method, 'PUT')
+    t.is(path, `namespaces/${ns}/actions/12345`)
+    t.deepEqual(options.qs, {})
+    t.deepEqual(options.body, { exec: { kind: 'nodejs:default', code: action }, limits: { concurrency: 2 } })
+  }
+
+  return actions.create({ name: '12345', action, limits })
+})
+
 test('create an action without providing an action body', t => {
   const actions = new Actions()
   t.throws(() => actions.create({ name: '12345' }), /Missing mandatory action/)
